==> k3b-trinity-3.5.13.2.tar.xz: k3b-trinity-3.5.13.2/src/projects/k3bmixedburndialog.h <==
/* 
 *
 * $Id: k3bmixedburndialog.h 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This file is part of the K3b project.
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */


#ifndef K3BMIXEDBURNDIALOG_H
#define K3BMIXEDBURNDIALOG_H

#include "k3bprojectburndialog.h"

class TQCheckBox;
class K3bWriterSelectionWidget;
class K3bTempDirSelectionWidget;
class K3bMixedDoc;
class K3bDataImageSettingsWidget;
class TQButtonGroup;
class TQRadioButton;
class K3bAudioCdTextWidget;
class K3bDataModeWidget;
class K3bIntMapComboBox;


/**
  *@author Sebastian Trueg
  */
class K3bMixedBurnDialog : public K3bProjectBurnDialog  
{
 Q_OBJECT
  TQ_OBJECT

 public:
   K3bMixedBurnDialog( K3bMixedDoc*, TQWidget *parent=0, const char *name=0, bool modal = true );

 protected:
   void loadK3bDefaults();
   void loadUserDefaults( KConfigBase* );
   void saveUserDefaults( KConfigBase* );
   void toggleAll();

   K3bDataImageSettingsWidget* m_imageSettingsWidget;
   K3bAudioCdTextWidget* m_cdtextWidget;

 protected slots:
   /**
    * Reimplemented for internal reasons (shut down the audio player)
    */
   void slotStartClicked();
   void saveSettings();
   void readSettings();

   void slotCacheImageToggled( bool on );
   void slotNormalizeToggled( bool on );

 private:
   void setupSettingsPage();
   K3bMixedDoc* m_doc;

   K3bIntMapComboBox* m_comboMixedModeType;
   TQRadioButton* m_radioMixedTypeFirstTrack;
   TQRadioButton* m_radioMixedTypeLastTrack;
   TQRadioButton* m_radioMixedTypeSessions;

   TQCheckBox* m_checkNormalize;

   K3bDataModeWidget* m_dataModeWidget;
};

#endif

==> k3b-trinity_14.0.12.orig.tar.xz: k3b-trinity-14.0.12/src/projects/k3bmixedburndialog.h <==
/* 
 *
 * $Id: k3bmixedburndialog.h 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This file is part of the K3b project.
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */


#ifndef K3BMIXEDBURNDIALOG_H
#define K3BMIXEDBURNDIALOG_H

#include "k3bprojectburndialog.h"

class TQCheckBox;
class K3bWriterSelectionWidget;
class K3bTempDirSelectionWidget;
class K3bMixedDoc;
class K3bDataImageSettingsWidget;
class TQButtonGroup;
class TQRadioButton;
class K3bAudioCdTextWidget;
class K3bDataModeWidget;
class K3bIntMapComboBox;


/**
  *@author Sebastian Trueg
  */
class K3bMixedBurnDialog : public K3bProjectBurnDialog  
{
 Q_OBJECT
  

 public:
   K3bMixedBurnDialog( K3bMixedDoc*, TQWidget *parent=0, const char *name=0, bool modal = true );

 protected:
   void loadK3bDefaults();
   void loadUserDefaults( TDEConfigBase* );
   void saveUserDefaults( TDEConfigBase* );
   void toggleAll();

   K3bDataImageSettingsWidget* m_imageSettingsWidget;
   K3bAudioCdTextWidget* m_cdtextWidget;

 protected slots:
   /**
    * Reimplemented for internal reasons (shut down the audio player)
    */
   void slotStartClicked();
   void saveSettings();
   void readSettings();

   void slotCacheImageToggled( bool on );
   void slotNormalizeToggled( bool on );

 private:
   void setupSettingsPage();
   K3bMixedDoc* m_doc;

   K3bIntMapComboBox* m_comboMixedModeType;
   TQRadioButton* m_radioMixedTypeFirstTrack;
   TQRadioButton* m_radioMixedTypeLastTrack;
   TQRadioButton* m_radioMixedTypeSessions;

   TQCheckBox* m_checkNormalize;

   K3bDataModeWidget* m_dataModeWidget;
};

#endif
